/*
 * Projeto: RMChartXDLL
 * Arquivo: RMChartXDLL.prg
 * Descrio: Uso da RMChart via Dll com sintaxe pelas classes OCX, para quem usa o RMCDesigner
 * Autor: F.C.Trautwein
 * Data: 08-21-2016
 */

#include "Xailer.ch"
#include "RMChartX.ch"

CLASS TRMChartXDll

   DATA oRM
   DATA oCrt
   DATA nIdChart

   DATA aRegion INIT {}
   DATA aCustomObjectText INIT {}

   DATA nAlign

   DATA RMCBackColor
   DATA RMCStyle
   DATA RMCWidth
   DATA RMCHeight
   DATA RMCBgImage
   DATA Font
   DATA RMCToolTipWidth
   DATA RMCHelpingGridSize
   DATA RMCHelpingGridColor
   DATA RMCBitmapColor

   METHOD New(oCrt)
   METHOD Create() INLINE Nil
   METHOD SetProperties( nWidth, nHeight, nBackColor, nStyle, sBgImage, sFont, nToolTipWidth, nGridSize, nGridColor, nBitmapColor )
   METHOD DeleteChart()
   METHOD Reset()
   METHOD Draw()
   METHOD Draw2Clipboard()
   METHOD Draw2Printer()
   METHOD Draw2File(cFileName)
   METHOD AddRegion()
   METHOD Region(n)
   METHOD AddCustomObjectText()
   METHOD CustomObjectText(n)

END CLASS

//---------------
METHOD New( oCrt, oRM, nIdChart ) CLASS TRMChartXDll
STATIC nIdCount:= 1000
::oCrt:= oCrt

IF oRM == Nil
   ::oRm:= RMChart():New()
ELSE
   ::oRm:= oRM
ENDIF

IF EMPTY( nIdChart )
   nIdChart:= nIdCount++
ELSE
   IF nIdChart > nIdCount
      nIdCount:= nIdChart
   ENDIF
ENDIF
::nIdChart:= nIdChart

RETURN Self

//---------------
METHOD SetProperties( nWidth, nHeight, nBackColor, nStyle, sBgImage, sFont, nToolTipWidth, nGridSize, nGridColor, nBitmapColor ) CLASS TRMChartXDll
::RMCBackColor       := nBackColor
::RMCStyle           := nStyle
::RMCWidth           := nWidth
::RMCHeight          := nHeight
::RMCBgImage         := sBgImage
::Font               := sFont
::RMCToolTipWidth    := nToolTipWidth
::RMCHelpingGridSize := nGridSize
::RMCHelpingGridColor:= nGridColor
::RMCBitmapColor     := nBitmapColor
RETURN Nil

//---------------
METHOD DeleteChart() CLASS TRMChartXDll
::oRM:DeleteChart(::nIdChart)
RETURN Nil

//---------------
METHOD Reset() CLASS TRMChartXDll
::oRM:Reset(::nIdChart)
RETURN Nil

//---------------
METHOD Draw2Clipboard() CLASS TRMChartXDll
::oRM:Draw2Clipboard(::nIdChart)
RETURN Nil

//---------------
METHOD Draw2Printer() CLASS TRMChartXDll
::oRM:Draw2Printer(::nIdChart)
RETURN Nil

//---------------
METHOD Draw2File(cFileName) CLASS TRMChartXDll
::oRM:Draw2File(::nIdChart,cFileName)
RETURN Nil

//---------------
METHOD Draw() CLASS TRMChartXDll
LOCAL nIdRegion, oRegion, oDataAxis, oLineSeries, oBarSeries, oCustomObjectText, nIdCustomObjectText, sTextProperties, i

IF ::nAlign == alCLIENT
   ::RMCWidth := ::oCrt:nWidth-3
   ::RMCHeight:= ::oCrt:nHeight-3
ENDIF

::oRm:CreateChart(;
    ::oCrt:Handle,;
    ::nIdChart,;
    0,;
    0,;
    ::RMCWidth,;
    ::RMCHeight,;
    ::RMCBackColor,;
    ::RMCStyle,;
    .F.,;
    ::RMCBgImage,;
    ::Font,;
    ::RMCHelpingGridSize,;
    ::RMCBitmapColor )

// Region
FOR EACH oRegion IN ::aRegion

   nIdRegion:= oRegion:__enumIndex()

   ::oRm:AddRegion(;
     ::nIdChart,;
     oRegion:Left,;
     oRegion:Top,;
     oRegion:Width,;
     oRegion:Height,;
     "",;
     .F. )

   // Grid
   IF !EMPTY( oRegion:oGrid )
      ::oRm:AddGrid(;
         ::nIdChart,;
         nIdRegion,;
         oRegion:oGrid:BackColor,;
         oRegion:oGrid:AsGradient,;
         oRegion:oGrid:Left,;
         oRegion:oGrid:Top,;
         oRegion:oGrid:Width,;
         oRegion:oGrid:Height,;
         oRegion:oGrid:BicolorMode )
   ENDIF

   // GridLessSeries
   IF !EMPTY( oRegion:oGridLessSeries )

      IF !EMPTY( oRegion:oGridLessSeries:DataString ) .and. EMPTY(oRegion:oGridLessSeries:DataArray)
         oRegion:oGridLessSeries:DataArray:= HB_ATokens( oRegion:oGridLessSeries:DataString, "*", .F., .F. )
         FOR i:= 1 TO LEN( oRegion:oGridLessSeries:DataArray )
            oRegion:oGridLessSeries:DataArray[i]:= VAL(oRegion:oGridLessSeries:DataArray[i])
         NEXT
      ENDIF

      ::oRm:AddGridLessSeries(;
         ::nIdChart,;
         nIdRegion,;
         oRegion:oGridLessSeries:DataArray,;
         LEN(oRegion:oGridLessSeries:DataArray),;
         oRegion:oGridLessSeries:aColorValue,;
         LEN(oRegion:oGridLessSeries:aColorValue),;
         oRegion:oGridLessSeries:SeriesStyle,;
         oRegion:oGridLessSeries:Alignment,;
         oRegion:oGridLessSeries:ExplodeMode,;
         oRegion:oGridLessSeries:Lucent,;
         oRegion:oGridLessSeries:ValueLabelOn,;
         oRegion:oGridLessSeries:HatchMode,;
         oRegion:oGridLessSeries:StartAngle )
   ENDIF

   // Legend
   IF !EMPTY(oRegion:oLegend)
      ::oRm:AddLegend(;
         ::nIdChart,;
         nIdRegion,;
         oRegion:oLegend:LegendString,;
         oRegion:oLegend:Alignment,;
         oRegion:oLegend:BackColor,;
         oRegion:oLegend:Style,;
         oRegion:oLegend:TextColor,;
         oRegion:oLegend:FontSize,;
         oRegion:oLegend:Bold )
   ENDIF

   // Caption
   IF !EMPTY(oRegion:oCaption)
      ::oRm:AddCaption(;
         ::nIdChart,;
         nIdRegion,;
         oRegion:oCaption:Titel,;
         oRegion:oCaption:BackColor,;
         oRegion:oCaption:TextColor,;
         oRegion:oCaption:FontSize,;
         oRegion:oCaption:Bold )
   ENDIF

   // LabelAxis
   IF !EMPTY( oRegion:oLabelAxis )
      ::oRm:AddLabelAxis(;
         ::nIdChart,;
         nIdRegion,;
         oRegion:oLabelAxis:LabelString,;
         oRegion:oLabelAxis:AxisCount,;
         oRegion:oLabelAxis:TickCount,;
         oRegion:oLabelAxis:Alignment,;
         oRegion:oLabelAxis:Fontsize,;
         oRegion:oLabelAxis:TextColor,;
         oRegion:oLabelAxis:TextAlignment,;
         oRegion:oLabelAxis:LineColor,;
         oRegion:oLabelAxis:LineStyle,;
         oRegion:oLabelAxis:AxisText )
   ENDIF

   // DataAxis
   FOR EACH oDataAxis IN oRegion:aDataAxis

      ::oRm:AddDataAxis(;
        ::nIdChart,;
        nIdRegion,;
        oDataAxis:Alignment,;
        oDataAxis:MinValue,;
        oDataAxis:MaxValue,;
        oDataAxis:TickCount,;
        oDataAxis:FontSize,;
        oDataAxis:TextColor,;
        oDataAxis:LineColor,;
        oDataAxis:LineStyle,;
        oDataAxis:DecimalDigits,;
        oDataAxis:AxisUnit,;
        oDataAxis:AxisText,;
        oDataAxis:LabelString,;
        oDataAxis:LabelTextAlignment )

   NEXT

   // LineSeries
   FOR EACH oLineSeries IN oRegion:aLineSeries

      IF !EMPTY( oLineSeries:DataString ) .and. EMPTY(oLineSeries:DataArray)
         oLineSeries:DataArray:= HB_ATokens( oLineSeries:DataString, "*", .F., .F. )
         FOR i:= 1 TO LEN( oLineSeries:DataArray )
            oLineSeries:DataArray[i]:= VAL(oLineSeries:DataArray[i])
         NEXT
      ENDIF

      ::oRm:AddLineSeries(;
        ::nIdChart,;
        nIdRegion,;
        oLineSeries:DataArray,;
        LEN(oLineSeries:DataArray),;
        oLineSeries:PointsPerColumnArray,;
        LEN(oLineSeries:PointsPerColumnArray),;
        oLineSeries:SeriesType,;
        oLineSeries:SeriesStyle,;
        oLineSeries:LineStyle,;
        oLineSeries:Lucent,;
        oLineSeries:Color,;
        oLineSeries:SymbolStyle,;
        oLineSeries:WhichDataAxis,;
        oLineSeries:ValueLabelOn,;
        oLineSeries:HatchMode )
   NEXT

   // BarSeries
   FOR EACH oBarSeries IN oRegion:aBarSeries

      IF !EMPTY( oBarSeries:DataString ) .and. EMPTY(oBarSeries:DataArray)
         oBarSeries:DataArray:= HB_ATokens( oBarSeries:DataString, "*", .F., .F. )
         FOR i:= 1 TO LEN( oBarSeries:DataArray )
            oBarSeries:DataArray[i]:= VAL(oBarSeries:DataArray[i])
         NEXT
      ENDIF

      ::oRm:AddBarSeries(;
        ::nIdChart,;
        nIdRegion,;
        oBarSeries:DataArray,;
        len(oBarSeries:DataArray),;
        oBarSeries:SeriesType,;
        oBarSeries:SeriesStyle,;
        oBarSeries:Lucent,;
        oBarSeries:Color,;
        oBarSeries:Horizontal,;
        oBarSeries:WhichDataAxis,;
        oBarSeries:ValueLabelOn,;
        oBarSeries:PointsPerColumn,;
        oBarSeries:HatchMode )

   NEXT

NEXT

// CustomObjectText
FOR EACH oCustomObjectText IN ::aCustomObjectText

   nIdCustomObjectText:= oCustomObjectText:__enumIndex()

   sTextProperties:= ""
   IF oCustomObjectText:FontBold
      sTextProperties+= "B"
   ENDIF
   IF !EMPTY(oCustomObjectText:FontSize)
      sTextProperties+= NTOC(oCustomObjectText:FontSize)
   ENDIF
   IF !oCustomObjectText:TextAlignment == Nil
      IF oCustomObjectText:TextAlignment == RMC_TEXTCENTER
         sTextProperties+= "C"
      ELSEIF oCustomObjectText:TextAlignment == RMC_TEXTLEFT
         sTextProperties+= "L"
      ELSE
         sTextProperties+= "R"
      ENDIF
   ENDIF

   ::oRm:COText(;
     ::nIdChart,;
     nIdCustomObjectText,;
     oCustomObjectText:Text,;
     oCustomObjectText:Left,;
     oCustomObjectText:Top,;
     oCustomObjectText:Width,;
     oCustomObjectText:Height,;
     oCustomObjectText:Style,;
     oCustomObjectText:BGColor,;
     oCustomObjectText:LineColor,;
     oCustomObjectText:Transparency,;
     oCustomObjectText:LineAlignment,;
     oCustomObjectText:TextColor,;
     sTextProperties )
NEXT

::oRm:Draw( ::nIdChart )

RETURN Nil

//---------------
METHOD AddRegion() CLASS TRMChartXDll

AADD( ::aRegion, TRMC_Region():New() )

RETURN Nil

//---------------
METHOD Region(n) CLASS TRMChartXDll
RETURN ::aRegion[n]

//---------------
METHOD AddCustomObjectText() CLASS TRMChartXDll

AADD( ::aCustomObjectText, TRMC_CustomObjectText():New() )

RETURN Nil

//---------------
METHOD CustomObjectText(n) CLASS TRMChartXDll
RETURN ::aCustomObjectText[n]

//------------------------------------------------------------------------------

CLASS TRMC_Region

   DATA oGrid
   DATA oGridLessSeries
   DATA aDataAxis   INIT {}
   DATA oLabelAxis
   DATA oLegend
   DATA oCaption
   DATA aLineSeries INIT {}
   DATA aBarSeries  INIT {}

   DATA Left
   DATA Top
   DATA Width
   DATA Height
   DATA Footer
   DATA ShowBorder

   METHOD New()
   METHOD SetProperties(nLeft, nTop, nWidth, nHeight, nShowBorder, sFooter)
   METHOD AddGrid()
   METHOD Grid()
   METHOD AddGridLessSeries()
   METHOD GridLessSeries()
   METHOD AddLegend()
   METHOD Legend()
   METHOD AddCaption()
   METHOD Caption()
   METHOD AddDataAxis()
   METHOD DataAxis(n)
   METHOD AddLabelAxis()
   METHOD LabelAxis(n)
   METHOD AddLineSeries()
   METHOD LineSeries(n)
   METHOD AddBarSeries()
   METHOD BarSeries(n)

END CLASS

//---------------
METHOD New() CLASS TRMC_Region
RETURN Self

//---------------
METHOD SetProperties(nLeft, nTop, nWidth, nHeight, nShowBorder, sFooter) CLASS TRMC_Region
::Left      := nLeft
::Top       := nTop
::Width     := nWidth
::Height    := nHeight
::ShowBorder:= nShowBorder
::Footer    := sFooter
RETURN Nil

//---------------
METHOD AddGrid() CLASS TRMC_Region

::oGrid:= TRMC_Grid():New()

RETURN Nil

//---------------
METHOD Grid() CLASS TRMC_Region
RETURN ::oGrid

//---------------
METHOD AddGridLessSeries() CLASS TRMC_Region

::oGridLessSeries:= TRMC_GridLessSeries():New()

RETURN Nil

//---------------
METHOD GridLessSeries() CLASS TRMC_Region
RETURN ::oGridLessSeries

//---------------
METHOD AddLegend() CLASS TRMC_Region

::oLegend:= TRMC_Legend():New()

RETURN Nil

//---------------
METHOD Legend() CLASS TRMC_Region
RETURN ::oLegend

//---------------
METHOD AddCaption() CLASS TRMC_Region

::oCaption:= TRMC_Caption():New()

RETURN Nil

//---------------
METHOD Caption() CLASS TRMC_Region
RETURN ::oCaption

//---------------
METHOD AddDataAxis() CLASS TRMC_Region

AADD( ::aDataAxis, TRMC_DataAxis():New() )

RETURN Nil

//---------------
METHOD DataAxis(n) CLASS TRMC_Region
RETURN ::aDataAxis[n]

//---------------
METHOD AddLabelAxis() CLASS TRMC_Region

::oLabelAxis:= TRMC_LabelAxis():New()

RETURN Nil

//---------------
METHOD LabelAxis(n) CLASS TRMC_Region
RETURN ::oLabelAxis

//---------------
METHOD AddLineSeries() CLASS TRMC_Region

AADD( ::aLineSeries, TRMC_LineSeries():New() )

RETURN Nil

//---------------
METHOD LineSeries(n) CLASS TRMC_Region
RETURN ::aLineSeries[n]


//---------------
METHOD AddBarSeries() CLASS TRMC_Region

AADD( ::aBarSeries, TRMC_BarSeries():New() )

RETURN Nil

//---------------
METHOD BarSeries(n) CLASS TRMC_Region
RETURN ::aBarSeries[n]

//------------------------------------------------------------------------------

CLASS TRMC_Grid

   DATA BackColor
   DATA AsGradient
   DATA BicolorMode
   DATA Left
   DATA Top
   DATA Width
   DATA Height

   METHOD New()
   METHOD SetProperties( nBackColor, nAsGradient, nLeft, nTop, nWidth, nHeight, nBicolor )

END CLASS

//---------------
METHOD New() CLASS TRMC_Grid
RETURN Self

//---------------
METHOD SetProperties( nBackColor, nAsGradient, nLeft, nTop, nWidth, nHeight, nBicolor ) CLASS TRMC_Grid
::BackColor  := nBackColor
::AsGradient := nAsGradient
::BicolorMode:= nBicolor
::Left       := nLeft
::Top        := nTop
::Width      := nWidth
::Height     := nHeight
RETURN Nil

//------------------------------------------------------------------------------

CLASS TRMC_GridLessSeries

   DATA aColorValue INIT {}

   DATA Alignment
   DATA ColorArray       INIT {}
   DATA ColorString
   DATA DataArray        INIT {}
   DATA DataFirstIndex
   DATA DataLastIndex
   DATA DataString
   DATA ExplodeMode
   DATA HatchMode
   DATA Lucent
   DATA NoData
   DATA SeriesStyle
   DATA StartAngle
   DATA ValueLabelOn

   METHOD New()
   METHOD SetProperties( nStyle, nAlignment, nExplodemode, nIsLucent, nValueLabelOn, nHatchMode, nStartAngle )
   METHOD SetColorValue( nIndex, nValue )

END CLASS

//---------------
METHOD New() CLASS TRMC_GridLessSeries
RETURN Self

//---------------
METHOD SetProperties( nStyle, nAlignment, nExplodemode, nIsLucent, nValueLabelOn, nHatchMode, nStartAngle ) CLASS TRMC_GridLessSeries

::Alignment     := nAlignment
::ExplodeMode   := nExplodemode
::HatchMode     := nHatchMode
::Lucent        := nIsLucent
::SeriesStyle   := nStyle
::StartAngle    := nStartAngle
::ValueLabelOn  := nValueLabelOn

RETURN Nil

//---------------
METHOD SetColorValue( nIndex, nValue )
LOCAL nLen, i
nLen:= LEN( ::aColorValue )
IF nLen < nIndex
   FOR i:= 1 TO nLen
      AADD( ::aColorValue, Default )
   NEXT
   AADD( ::aColorValue, nValue )
ELSE
   ::aColorValue[ nIndex ]:= nValue
ENDIF
RETURN Nil

//------------------------------------------------------------------------------

CLASS TRMC_Legend

   DATA Alignment
   DATA BackColor
   DATA Bold
   DATA FontSize
   DATA Hide
   DATA LegendString
   DATA LegendText
   DATA LegendTextArray
   DATA Style
   DATA TextColor

   METHOD New()
   METHOD SetProperties( nAlignment, nBackColor, nStyle, nTextColor, nFontsize, nBold )

END CLASS

//---------------
METHOD New() CLASS TRMC_Legend
RETURN Self

//---------------
METHOD SetProperties( nAlignment, nBackColor, nStyle, nTextColor, nFontsize, nBold ) CLASS TRMC_Legend
::Alignment      := nAlignment
::BackColor      := nBackColor
::Bold           := nBold
::FontSize       := nFontsize
::Style          := nStyle
::TextColor      := nTextColor
RETURN Nil

//------------------------------------------------------------------------------

CLASS TRMC_Caption

   DATA BackColor
   DATA Bold
   DATA FontSize
   DATA TextColor
   DATA Titel

   METHOD New()
   METHOD SetProperties( sCaption, nBackColor, nTextColor, nFontsize, nBold )

END CLASS

//---------------
METHOD New() CLASS TRMC_Caption
RETURN Self

//---------------
METHOD SetProperties( sCaption, nBackColor, nTextColor, nFontsize, nBold ) CLASS TRMC_Caption
::BackColor:= nBackColor
::Bold     := nBold
::FontSize := nFontsize
::TextColor:= nTextColor
::Titel    := sCaption
RETURN Nil

//------------------------------------------------------------------------------

CLASS TRMC_DataAxis

   DATA Alignment
   DATA AxisText
   DATA AxisUnit
   DATA FontSize    INIT 8
   DATA LabelString INIT ""
   DATA LabelTextArray
   DATA LabelTextAlignment
   DATA LineColor
   DATA LineStyle
   DATA MaxValue
   DATA MinValue
   DATA DecimalDigits
   DATA TextColor
   DATA TickCount

   METHOD New()
   METHOD SetProperties( nAlignment, nMinValue, nMaxValue, nTickCount, nFontsize, nTextColor, nLineColor, nLineStyle,;
                      nDecimalDigits, sAxisUnit, sAxisText, sAxisLabels, nLabelTextAlignment )

END CLASS

//---------------
METHOD New() CLASS TRMC_DataAxis
RETURN Self

//---------------
METHOD SetProperties( nAlignment, nMinValue, nMaxValue, nTickCount, nFontsize, nTextColor, nLineColor, nLineStyle,;
                      nDecimalDigits, sAxisUnit, sAxisText, sAxisLabels, nLabelTextAlignment ) CLASS TRMC_DataAxis
::Alignment         := nAlignment
::AxisText          := sAxisText
::AxisUnit          := sAxisUnit
::FontSize          := nFontsize
//::LabelString       := sAxisLabels
//::LabelTextAlignment:= nLabelTextAlignment
::LineColor         := nLineColor
::LineStyle         := nLineStyle
::MaxValue          := nMaxValue
::MinValue          := nMinValue
::DecimalDigits     := nDecimalDigits
::TextColor         := nTextColor
::TickCount         := nTickCount
RETURN Nil

//------------------------------------------------------------------------------

CLASS TRMC_LabelAxis

   DATA Alignment
   DATA AxisCount
   DATA AxisText
   DATA Fontsize
   DATA LabelFirstIndex
   DATA LabelLastIndex
   DATA LabelString
   DATA LabelText
   DATA LabelTextArray
   DATA LineColor
   DATA LineStyle
   DATA TextAlignment
   DATA TextColor
   DATA TickCount

   METHOD New()
   METHOD SetProperties( nCount, nTickCount, nAlignment, nFontsize, nTextColor, nTextAlignment, nLineColor, nLineStyle )

END CLASS

//---------------
METHOD New() CLASS TRMC_LabelAxis
RETURN Self

//---------------
METHOD SetProperties( nCount, nTickCount, nAlignment, nFontsize, nTextColor, nTextAlignment, nLineColor, nLineStyle ) CLASS TRMC_LabelAxis
::Alignment      := nAlignment
::AxisCount      := nCount
::Fontsize       := nFontsize
::LineColor      := nLineColor
::LineStyle      := nLineStyle
::TextAlignment  := nTextAlignment
::TextColor      := nTextColor
::TickCount      := nTickCount
RETURN Nil

//------------------------------------------------------------------------------

CLASS TRMC_LineSeries

   DATA Color
   DATA DataArray                INIT {}
   DATA DataFirstIndex
   DATA DataLastIndex
   DATA DataString
   DATA HatchMode
   DATA LineStyle
   DATA Lucent
   DATA NoData
   DATA PointsPerColumnArray     INIT {}
   DATA PointsPerColumnString
   DATA PointsPerColumnValue
   DATA SeriesStyle
   DATA SeriesType
   DATA SymbolStyle
   DATA ValueLabelOn
   DATA WhichDataAxis

   METHOD New()
   METHOD SetProperties( nType, nStyle, nLineStyle, nIsLucent, nColor, nSeriesSymbol, nWhichDataAxis, nValueLabelOn, nHatchMode )

END CLASS

//---------------
METHOD New() CLASS TRMC_LineSeries
RETURN Self

//---------------
METHOD SetProperties( nType, nStyle, nLineStyle, nIsLucent, nColor, nSeriesSymbol, nWhichDataAxis, nValueLabelOn, nHatchMode ) CLASS TRMC_LineSeries
::Color                := nColor
::HatchMode            := nHatchMode
::LineStyle            := nLineStyle
::Lucent               := nIsLucent
::SeriesStyle          := nStyle
::SeriesType           := nType
::SymbolStyle          := nSeriesSymbol
::ValueLabelOn         := nValueLabelOn
::WhichDataAxis        := nWhichDataAxis
RETURN Nil

//------------------------------------------------------------------------------

CLASS TRMC_BarSeries

   DATA Color
   DATA ColorArray
   DATA ColorString
   DATA DataArray          INIT {}
   DATA DataFirstIndex
   DATA DataLastIndex
   DATA DataString
   DATA HatchMode
   DATA Horizontal
   DATA Lucent
   DATA NoData
   DATA PointsPerColumn
   DATA SeriesStyle
   DATA SeriesType
   DATA ValueLabelOn
   DATA WhichDataAxis

   METHOD New()
   METHOD SetProperties( nType, nStyle, nIsLucent, nColor, nIsHorizontal, nWhichDataAxis, nValueLabelOn, nPointsPerColumn, nHatchMode )

END CLASS

//---------------
METHOD New() CLASS TRMC_BarSeries
RETURN Self

//---------------
METHOD SetProperties( nType, nStyle, nIsLucent, nColor, nIsHorizontal, nWhichDataAxis, nValueLabelOn, nPointsPerColumn, nHatchMode ) CLASS TRMC_BarSeries
::Color          := nColor
::HatchMode      := nHatchMode
::Horizontal     := nIsHorizontal
::Lucent         := nIsLucent
::PointsPerColumn:= nPointsPerColumn
::SeriesStyle    := nStyle
::SeriesType     := nType
::ValueLabelOn   := nValueLabelOn
::WhichDataAxis  := nWhichDataAxis
RETURN Nil

//------------------------------------------------------------------------------

CLASS TRMC_CustomObjectText

   DATA BGColor
   DATA FontBold       INIT .f.
   DATA FontSize       INIT 0
   DATA Height
   DATA Hide
   DATA Left
   DATA LineAlignment
   DATA LineColor
   DATA Style
   DATA Text
   DATA TextAlignment  INIT 0
   DATA TextColor
   DATA Top
   DATA Transparency
   DATA Width
   DATA WidthHeight

   METHOD New()
   METHOD SetProperties( sText, nLeft, nTop, nWidth, nHeight, nStyle, nBGColor, nLineColor, nTransparency, nLineAlignment, nTextColor, nTextAlignment, nFontBold, nFontSize )

END CLASS

//---------------
METHOD New() CLASS TRMC_CustomObjectText
RETURN Self

//---------------
METHOD SetProperties( sText, nLeft, nTop, nWidth, nHeight, nStyle, nBGColor, nLineColor, nTransparency, nLineAlignment, nTextColor, nTextAlignment, nFontBold, nFontSize ) CLASS TRMC_CustomObjectText
::BGColor      := nBGColor
::FontBold     := nFontBold
::FontSize     := nFontSize
::Height       := nHeight
::Left         := nLeft
::LineAlignment:= nLineAlignment
::LineColor    := nLineColor
::Style        := nStyle
::Text         := sText
::TextAlignment:= nTextAlignment
::TextColor    := nTextColor
::Top          := nTop
::Transparency := nTransparency
::Width        := nWidth
RETURN Nil

//------------------------------------------------------------------------------





